/*********************************************************************
    This file is part of Siworin. Copyright © 2021 by Ruud Harmsen.

    Siworin is a simple word indexer and local search engine. See
    https://rudhar.com/sfreview/siworin/#siw04 and
    https://rudhar.com/sfreview/siworin/toolsrc/siworin .

    Siworin is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published
    by the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    Siworin is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Siworin.  If not, see <https://www.gnu.org/licenses/>.
  ********************************************************************/

#ifndef _SIWORIN_FILES_H
#define _SIWORIN_FILES_H

#include <stdio.h>

/* File pointer for a file that contains paths to the HTML files, one per line. */
extern FILE *siworin_fp_paths;
/* File pointer for an index to the above file. Each line contains the byte offset
   of the start of each line in the other file. */
extern FILE *siworin_fp_pathoffs;
/* File pointer for a file with words, and address pair indicating their
   occurrences in the HTML files. */
extern FILE *siworin_fp_words;
/* File pointer for an index to the above file. Each line contains the byte offset
   of the start of each line in the other file. */
extern FILE *siworin_fp_wordoffs;
/* File pointer for an optional file containing the number of occurrences
   of each of the words. */
extern FILE *siworin_fp_wordfreq;

/* Opens files and sets siworin_fp_paths and siworin_fp_pathoffs.
   Return 0 upon success, non-zero otherwise. */
int siworin_fileopen_paths (
   const char *file_prefix, const char *mode_paths, const char *mode_pathoffs);

/* Opens files and sets siworin_fp_words and siworin_fp_wordoffs.
   Returns 0 upon success, non-zero otherwise. */
int siworin_fileopen_words (
   const char *file_prefix, const char *mode_words, const char *mode_wordoffs);

/* Closes all four files, if open, and marks the pointers as NULL. */
int siworin_fileopen_close (void);

#endif
